# HuBMAP Template Helper Package

This is a package with helper functions for using data from the [HuBMAP Data Portal](https://portal.hubmapconsortium.org).

It is used in various [templates](https://github.com/hubmapconsortium/user-templates-api).

Please refer to the [tutorial](https://github.com/thomcsmits/hubmap_template_helper/blob/main/tutorial.ipynb) to see the usage.
